% --------------------------------------------------------------------------
%  Nonlinear modes of a spring-mass system by HBM with MANLAB
%  -------------------------------------------------------------------------
%
%      \|   spring 1
%      \|------------O mass  
%      \|            |
%                    | spring 2
%                    |    
%                  - - -
%                  \ \ \
%
%   u1(t) : x displacement of the mass 
%   u2(t) : y displacement of the mass
%
%   e1= u1 + 1/2 (u1^2 + u2^2)  strain for spring 1 (Green-lagrange)
%   e2= u2 + 1/2 (u1^2 + u2^2)  strain for spring 2
%
%   N1= k1 e1    spring force (ki : stiffness)
%   N2= k2 e2 
%
%   W= 1/2 k1  e1^2 + 1/2 k2  e2^2  strain energy
%   m mass (m=1)
%
%   Model equations     
%   ---------------
%   m u1''  + d W/d u1 =0
%   m u2''  + d W/d u2 =0
%   
%   m u1'' + N1 (1+u1) + N2 (u1)   =0 
%   m u2'' + N1 (u2)   + N2 (1+u2) =0
%
%   The system is autonomous and conservative. It has a first integral corresponding
%   to the conservation of the total energy.
%   It is quite different from dissipative systems, in terms of periodic solutions.
%   In dissipative systems, periodic solution are generically isolated
%   and an external parameter is required in order to continue the familly 
%   of periodic orbits (see Van der Pol, for example).
%   In conservative (Hamiltonian) system, periodic orbit generally belongs to 
%   one-dimensional familly of periodic solution, parametrized by the value of the
%   first integral (here, the total energy). These one-dimensional famillies of
%   periodic orbits are the non linear modes of the system.
%
%   It is convenient to have the same framework and the same software to find
%   the branche of periodic solution of dissipative system and the non linear modes
%   of conservative ones. 
%   To put the conservative system into the usual framework (dissipative with one parameter)
%   we add dissipative terms  lambda u1' and lambda u2' in each equation. 
%
%   m u1'' + lambda u1'  +  N1 (1+u1) + N2 (u1)   = 0 
%   m u2'' + lambda u2'  +  N1 (u2)   + N2 (1+u2) = 0
%
%   This new system is dissipative and it has a free parameter, lambda.
%   It is easy to show that periodic solution can occur only when lambda is zero.
%   So, this dissipative (with a parameter) has the same periodic solution
%   as the conservative one (see Munoz-Almaraz Freire Galan Doedel Vanderbauwhede
%   "Continuation of periodic orbits in conservative and Hamiltonian system",
%   Physica D, 181, 1-38, 2003)
%
%   
%   We transform into first order system bu introducing   v1 = u1' and v2 = u2'
%                  
%   Finally we have,
%
%    u1'  =     v1
%    u2'  =     v2 
%    v1'  = -1/m ( lambda u1'  +N1 +  u1 (N1+N2) )
%    v2'  = -1/m ( lambda u2'  +N2 +  u2 (N1+N2) )  
%    0    =  N1 - k1 u1  - k1/2 (u1^2 + u2^2)
%    0    =  N2 - k2 u2  - k2/2 (u1^2 + u2^2)
%
%    With  Z(t) = [ u1, u2 , v1, v2 , N1 , N2 ]  (Neq=6) the system becomes
%  
%   -->   m(Z') = c0 + lambda c1  +l0(Z) + lambda l1(Z) + q(Z,Z) 
%
%  Here c0=c1=0
%
%  Harmonic balance
%  ----------------
%
%
%  Z(t) = Z0 + Z1c cos(omega t) + Z1s sin(omega t) + Z2c cos(2 Omega t) + Z2s sin(2 Omega t) + ... 
%              ...  + ZHc cos(H omega t) + ZHs sin(H omega t).
%
%  the balance of the harmonics leads to a large system of size  Neq*(2H+1)
%
%      C0    +     lambda C1 + L0(U)         + lambda L1(U) + Q(U,U) - omega M(U)= 0 
%    constant         linear                            quadratic
%                  
%
%     with    U=[Z0  Z1c Z1s  Z2c Z2s  ...  ZHs ]
%  
%
%  Final algebraic system for Manlab  bL0 + bL(bU) + bQ(bU,bU) =0 
%  --------------------------------------------------------------
%
%   bU = [ U , lambda, omega ]
%
%   bL0       = C0
%   bL(bu)    = L0(U) + lambda C1
%   bQ(bU,bU) = Q(U,U) + lambda L1(U) - omega M(U)
%
%
%--------------------------------------------------------------------------

close all; clear all; clear classes;

% Add the path to your MANLAB source directory (if not in your pathdef.m)
addpath('~/MANLAB-2.0-beta/SRC')


% initialise all MANLAB variables and parameters
manlabinit;

%% Problem size and parameters
% number of harmonics for the HBM
H=10;
% number of equation of the quadratic system (before HBM equations)
Neq=6;

%%% Parameters : make sure you modify their values in
%%%     the preamble of petits_operateurs.f90
%%% or in the matlab functions 'L0.m', 'L.m' and 'Q.m'


%% Fortran acceleration : compilation
% comment the following line to ignore Fortran acceleration
[status,result]=unix('cd @DEUXRES && make && cd ..','-echo');
% uncomment the following to remove Fortran acceleration
% [status,result]=unix('cd @DEUXRES && make clean && cd ..','-echo');

% Creating the object of class 'DEUXRES'
ML_problem  = DEUXRES(H,Neq);     

%% Change a few ANM parameters (optional)
% % number of points per portion to be evaluated for display
% ML_problem = set_nbptstroncon(ML_problem,20);
% % order of the power series in the ANM (default : 20)
% ML_problem = set_ordre(ML_problem,15);
% % number of time samples for monodromy matrix computation (used if
% % ML_algostab=1 only)
% ML_problem = set_nech(ML_problem,1000);



%% Starting point (approx.)
ML_Ustart   = zeros((2*H+1)*Neq+2,1); 

%%% on mode 1, harmonic 1
ML_Ustart(7:18)=[ 0.1  0  0  0  0.1  0   0  0  -0.1  0  0 0   ]; 
ML_Ustart(end-1:end) =  [0.001  1];

%%% mode 1 on harmonic 2
% ML_Ustart(19:30)=[ 0.1  0  0  0  0.1  0   0  0  -0.1  0  0 0   ];
% ML_Ustart(end-1:end) =  [0.001 1]; 

%% Variables we want to be displayed
% use the form : [abscissa1,ordinate1; abscissa2,ordinate2...]
ML_dispvars = [  (2*H+1)*Neq+2  Neq+1 ; (2*H+1)*Neq+2  2*Neq+1 ; (2*H+1)*Neq+2 3*Neq+1 ; (2*H+1)*Neq+2 4*Neq+1 ];   

%% Stability analysis : which variables are needed for the jacobian
% ML_varstab = [ index1 index2 ... index_of_lambda index_of_omega H ]
% Here we need only U(1), so index is 1.
ML_varstab = [ 1  2  (2*H+1)*Neq+1 (2*H+1)*Neq+2 H ] ;
 
%% Various parameters for MANLAB
% Do we want to compute the stability analysis ([1=yes], 0=no)
ML_stability = 1;
% If yes, which algo should be used (1=time integ., [2=Hill])
ML_algostab = 2;
 
% Do we want to display point-specific plots
ML_pointdisplay = 1;
% Do we want to display user defined global plots (like bif. diag., ...)
ML_globaldisplay = 0;

%% Start the programm
manlabstart
