%   ================================================================
%   Periodic solutions of two oscillators with quadratic
%   nonlinearities in 1:2 internal resonance
%   Excitation of the HIGH-FREQUENCY mode.
%
%   Observe two Period doubling (PD) bifurcations around 
%   omega=1.95 and omega=2.05
%
%   Ref.:
%     * Nayfeh, A. H. & Mook, D. T. "Nonlinear Oscillations",
%       Wiley, 1979
%     * O. Thomas, C. Touze & A. Chaigne "Non-linear vibrations of
%       free-edge thin spherical shells: modal interaction rules and
%       1:1:2 internal resonance", International Journal of Solids
%       and Structures, 2005, Vol. 42, pp. 3339-3373
%   ================================================================
%
%   Initial dynamical system:
%   -------------------------
%  
%   (1)   u1'' + mu1 u' + om1^2 u1 + beta1 u1 u2 = 0
%         u2'' + mu2 u' + om2^2 u2 + beta2 u1^2  = F cos(omega t)  
%   
%   u1(t), u2(t) are real unknown time functions. The other parameters are
%   real.
%
%   First order dynamical system
%   ----------------------------
%
%   We introduce:
%
%         v1=u1' 
%         v2=u2'
%
%   to transform (1) into the first order dynamical system:
%
%   (2)   u1'  =                    + v1
%         u2'  =                    + v2
%         v1'  =                    - mu1 v1  - beta1 * u1 * u2 
%         v2'  =    F cos(omega t)  - om2^2 u2  - mu2 v2  - beta2 * u1^2
%   
%   The Jacobian writes:
%
%   J = [ 0                 0          1    0;
%         0                 0          0    1;
%        -om1^2 -beta1*u2  -beta1*u1  -mu1  0;
%        -2*beta2*u1       -om2^2      0   -mu2 ];
%
%   or:
%
%   J0 = [ 0      0       1    0;
%          0      0       0    1;
%         -om1^2  0      -mu1  0;
%          0     -om2^2   0   -mu2 ];
%
%   JL = [ 0          0        0    0;
%          0          0        0    0;
%         -beta1*u2  -beta1*u1 0    0;
%         -2*beta2*u1 0        0    0];
%
%   JQ = 0
%
%   Quadratic dynamical system
%   --------------------------
%   
%   (2) is naturally quadratic with Neq=4 equations
%
%   Small operators formalism
%   -------------------------
% 
%   The following formalism is introduced:
%
%         m(u') = c + l(u) + q(u,u)
%
%   where: 
%
%         u(t)=[u1 v1 u2 v2]
%         c is a constant operator in vector u
%         l(u) is a linear operator in vector u
%         q(u,u) is a quadratic operator in vector u
%
%   Harmonic Balance Method (HBM)
%   -----------------------------
% 
%   The Harmonic Balance method (HBM) leads to seak vector u(t) in a
%   Fourier series truncated to H harmonics:
%
%        u(t) = u0 + 
%               u1c cos(omega t) + u1s sin(omega t) + 
%               u2c cos(2 Omega t) + u2s sin(2 Omega t) + 
%               ... +
%               uHc cos(H omega t) + uHs sin(H omega t)
%
%   which leads to a nonlinear algebraic system of Neq*(2*H+1)
%   equations of the form:
%
%        C  + L(U)  - omega M(U) + Q(U,U)  = 0 
%
%   where 
%
%        U=[u0 u1c u1s  u2c u2s  ...  uHs]
%  
%   Final algebraic system for Manlab  
%   ---------------------------------
% 
%        R(bU) = bL0 + bL(bU) + bQ(bU,bU) =0 
%
%   with
%
%        bU = [U omega]
%
%        bL0       = C
%        bL(bU)    = L(U)
%        bQ(bU,bU) = Q(U,U) - omega M(U)
%
%   Computing bL0, bL, and bQ as functions of c, l, m and q is
%   automatic.
%
%   By O. Thomas - Oct. 2010
%
% ====================================================================

% Path for the Manlab sources
addpath('/home/thomas/Matlab/MANLAB/MANLAB-2.0-beta/SRC')
addpath('/home/thomas/Matlab/MANLAB/MANLAB-2.0-beta/SRC_VISU')

clear classes
clear all
% Manlab initialisation
manlabinit;

% Parameters
% ----------
 
% Generic for HBM 
H= 6;        % Number of harmonics
Neq=4;        % Number of equations of the quadratic system   

% Particular for this example

% Mode 1 -> low frequency mode
% Mode 2 -> high frequency mode

om1=1;           % Mode 1 angular frequency
sig1=0;          % Detuning between mode 2 and mode 1
xi1=.005;        % Damping factor of mode 1
xi2=.005;        % Damping factor of mode 2
F=.2;            % Forcing
beta1=.1;        % NL coefficient
beta2=.1;        % NL coefficient
 
om2=2*om1+sig1;  % Mode 2 angular frequency
mu1=2*xi1*om1;   % Twice the damping coefficient of mode 1
mu2=2*xi2*om2;   % Twice the damping coefficient of mode 2
om1c=om1^2;      % Mode 1 angular frequency squared
om2c=om2^2;      % Mode 2 angular frequency squared
 
% Object creation
% ---------------
 
ML_problem  = RESON21_OM(H,Neq,om1c,om2c,mu1,mu2,beta1,beta2,F);

% Stability computation parameters
% --------------------------------

ML_stability = 1; % 1/0: stability computation activation/desactivation
ML_algostab = 2;  % 1 -> time domain algorithm
                  % 2 -> frequency domain algorithm

% Entry vector for stability computations:
% which variables are needed for the Jacobian
% ML_varstab=[Ustab lambda omega H];
% Ustab -> indices in the small vector u
% Here (non autonomous system), continuation parameter lambda = omega
% omega -> Neq*(2*H+1)+1 (indices in big vector bU)
ML_varstab = [1 2 Neq*(2*H+1)+1 Neq*(2*H+1)+1 H];

% Tolerance on the stability check
% |rho| > 1+tolstab -> unstable
ML_tolstab=0;
% Order of the power series order for ANM branches
ML_problem = set_ordre(ML_problem,15);         
% number of point in a ANM branch for display and stability computation
ML_problem = set_nbptstroncon(ML_problem,20);
% number of time sample in a period for time domain stability computation 
% (only used if ML_algostab=1)
ML_problem = set_nech(ML_problem,1000);        
 
% Starting vector for the initial Newton-Raphson algorithm
% --------------------------------------------------------

ML_Ustart  = zeros(Neq*(2*H+1)+1,1);
ML_Ustart(end)= 1.8;
 
% Indices of variables to be displayed on the main bifurcation
% diagram of figure(2) 
% -------------------------------------------------------------- 

% ML_dispvars = [x1 y1 ; x2 y2; ...]
% omega -> (2*H+1)*Neq+1

ML_dispvars = [(2*H+1)*Neq+1  Neq+1   ; % H1 de u1 en cos 
	       (2*H+1)*Neq+1  Neq+2   ; % H1 de u2 en cos
	       (2*H+1)*Neq+1  2*Neq+1 ; % H1 de u1 en sin
	       (2*H+1)*Neq+1  2*Neq+2 ; % H1 de u2 en sin
               (2*H+1)*Neq+1  3*Neq+1 ; % H2 de u1 en cos 
	       (2*H+1)*Neq+1  3*Neq+2 ; % H2 de u2 en cos
	       (2*H+1)*Neq+1  4*Neq+1 ; % H2 de u1 en sin
	       (2*H+1)*Neq+1  4*Neq+2]; % H2 de u2 en sin
                
% Activation of point display and global display
% ----------------------------------------------

ML_pointdisplay = 0;
ML_globaldisplay = 0;
 
% Manlab start
% ------------

manlabstart; 

