% plotIMHBM   Invariant Manifold / Nonlinear Mode plot
%    Hand=plotIMHBM(Neq,H,U,Idisp,Ia,fig) plots the
%    surface of the invariant manifold related to the three
%    dinamical system unknown which indices are in Idisp 
%
%    U is the vector of unknowns of the final algebraic system solved
%    by Manlab. 
% 
%    Idisp is a vector of length 3 containing  the indices of the
%    entries of the three initial physical unknown vector u(t) 
%    related to the IM.
%
%    Ia is a vector of indices of the %%%%%%
%
%    H is the number of harmonics of the simulation.
%
%    Neq is the number of equations of the initial system of unknown
%    u(t)
% 
%    fig is a figure/axis handle to plot the bargraph on.
%
%    It returns in Hand a column vector of handles to lineseries objects, 
%    one handle per plotted line. 
%
%    Hand=plotIMHBM(Neq,H,U,Idisp,Ia,fig,Nech)
%    Hand=plotIMHBM(Neq,H,U,Idisp,Ia,fig,tt)
%
%    Example: plotNNMHBM(Neq,H,ML_Ud,[2 4 1],100:10:700,1,linspace(0.5,1,360/2));
%
%    By O. Thomas / Sept. 2010


function Hand=plotIMHBM(Neq,H,U,Idisp,Ia,fig,varargin)


if length(Idisp)~=3
  disp('length(Idisp) should be 3')
  return
end 


% Activate axis
% =============

if floor(fig)==fig
  figure(fig)
  clf
  hold on
else
  axes(fig)
  hold on
end

% Plotting
% ========

if isempty(varargin)
  Nech=360/2;
  tt=linspace(0,1,Nech);
  tt=tt';
elseif length(varargin{1})==1
  Nech=varargin{1};
  tt=linspace(0,1,Nech);
  tt=tt';
else
  tt=varargin{1};
end


Ndisp=length(Idisp);
Na=length(Ia);
Nech=length(tt);

if size(tt,1)<size(tt,2)
  tt=tt';
end

if min(Ia)>size(U,2)
  disp('min(Ia) should be <= size(U,2)')
  return
end
 
if max(Ia)>size(U,2)
  disp('max(Ia) should be <= size(U,2)')
  return
end


Uplot=zeros(Nech,Na,Ndisp);

for ii=1:Ndisp
  idisp=Idisp(ii);
  for jj=1:Na
    ia=Ia(jj);
    Iloc=idisp:Neq:(2*H+1)*Neq;
    Uloc=U(Iloc,ia);
    utt=calc_periodic(Uloc,tt);
    Uplot(:,jj,ii)=utt;
  end
end

%subplot(2,1,1)
%hold on
%for ii=1:Na
%  plot3(Uplot(:,ii,1),Uplot(:,ii,2),Uplot(:,ii,3))
%end
%xlabel(['u_',num2str(Idisp(1))])
%ylabel(['u_',num2str(Idisp(2))])
%zlabel(['u_',num2str(Idisp(3))])
%view(-20,40)

%subplot(2,1,2)
Hand=surf(Uplot(:,:,1),Uplot(:,:,2),Uplot(:,:,3),Uplot(:,:,3));%,'FaceColor',[0.9  0.5 0],'EdgeColor','k','FaceLighting','phong')
axis tight
view(-50,30)
%h=camlight('left')
grid on

xlabel(['u_',num2str(Idisp(1))])
ylabel(['u_',num2str(Idisp(2))])
zlabel(['u_',num2str(Idisp(3))])
view(-30,40)
box on

function utt=calc_periodic(U,tt);
% Cette fonction calcule une serie temporelle 
% periodique, connaissant l'amplitude de ses
% harmonique en sinus et cosinus.
%
% u(t)=U0 + U1c cos t + U1s sin t + ... + UHc cos H*t + UHs sin H*t
% U=[U0 U1c U1s U2c U2s ... UHc UHs]

L=length(U);
H=(L-1)/2;
utt=ones(size(tt))*U(1);

for hh=1:H
  utt=utt+U(2*hh)*cos(2*pi*hh*tt)+U(2*hh+1)*sin(2*pi*hh*tt);
end


