% plotperiodHBM   Periodic solution time plot
%    Hand = plotperiodHBM(H,Neq,U,Idisp,fig) plots two periods of the
%    periodic solution computed by the Manlab/HBM method.
%
%    U is the vector of unknowns of the final algebraic system solved
%    by Manlab. 
% 
%    Idisp contains the indices of the entries of the initial physical 
%    unknown vector u(t) to be displayed.
%
%    H is the number of harmonics of the simulation.
%
%    Neq is the number of equations of the initial system of unknown
%    u(t)
% 
%    fig is a figure/axis handle to plot the bargraph on.
%
%    It returns in Hand a column vector of handles to lineseries objects, 
%    one handle per plotted line. 
%
%    Example: Hand=plotperiodHBM(obj.H,obj.Neq,U,[1 2],1)
%
%    By O. Thomas / Sept. 2010

function  Hand=plotperiodHBM(H,Neq,U,Idisp,fig)

% Activate axis
% =============

if floor(fig)==fig
  figure(fig)
  clf
  hold on
else
  axes(fig)
  hold on
end

% Plotting
% ========

Hand=[];
Ndisp=length(Idisp);

%map=colormap;
%Icol=floor(linspace(1,64,Ndisp+2));
%Icol=Icol(2:end-1);
%Icol=Icol';
%Col=map(Icol,:);

pencolorML;

for ii=1:length(Idisp)
  Itrac=Idisp(ii):Neq:(2*H+1)*Neq;
  Utrac=U(Itrac);
  hand=trac_periodic(Utrac,2,Col(ii,:));
  Hand=[Hand;hand];
  Leg{ii}=['u_',num2str(Idisp(ii))];
end
legend(Hand,Leg);

function  hand=trac_periodic(U,Nper,col)
% Cette fonction trace Nper periodes d'une serie temporelle 
% periodique, connaissant l'amplitude de ses
% harmonique en sinus et cosinus.
%
% u(t)=U0 + U1c cos t + U1s sin t + ... + UHc cos H*t + UHs sin H*t
% U=[U0 U1c U1s U2c U2s ... UHc UHs]
%
% function hand=trac_periodic(U,Nper);

L=length(U);
H=(L-1)/2;

if (H-floor(H))~=0
  disp('Mauvaise taille de vecteur U')
  Umax=NaN;Umin=NaN;Umoy=NaN;
  tmin=NaN;tmax=NaN;
  return
end

Nech=1000*H;
tt=linspace(0,1,Nech);

utt=ones(size(tt))*U(1);

for hh=1:H
  utt=utt+U(2*hh)*cos(2*pi*hh*tt)+U(2*hh+1)*sin(2*pi*hh*tt);
end

[Umax,I]=max(utt);
tmax=tt(min(I));
[Umin,I]=min(utt);
tmin=tt(min(I));
Umoy=mean(utt);
%disp(['Max: ',num2str(Umax),' - Min: ',num2str(Umin),' - Moy: ',num2str(Umoy)])
hold on
Tt=[];
Utt=[];
for ii=1:Nper
  Tt=[Tt tt+ii-1];
  Utt=[Utt utt];
end
hand=plot(Tt,Utt,'Color',col,'Linewidth',1);
Ylim=[Umin-.1*(Umax-Umin) Umax+.1*(Umax-Umin)];
Ylim2=[Umin-10*(Umax-Umin) Umax+10*(Umax-Umin)];
%  plot([1 1],Ylim2,'k:')
%  set(gca,'Ylim',Ylim)
xlabel('Time t/T [adim]')
box on
plot([0 Nper],[0 0],'k:')

